Module inputs

Module inputs 

Inputs are things that a person or other device (such as the host) can do to cause a behavior.

Examples include:

  • Analog inputs from hall effect sensors or a varistor
  • Momentary switches from a traditional keyboard switch
  • Messages from software on a host machine or other device

Modules

analog
binary

Traits

Input
Structs that implement the Input trait represent physical or logical inputs to the keyboard. They can be anything from a momentary switch seen in typical keyboards to analog inputs from hall effect sensors or a varistor, to inputs from software on a host machine
InputConfig
Marker trait indicating that the implementing struct can be used as a configuration which read a signal of type S
InputConfigurator
Defines (typically at the hardware level) how a configured input is read.