Input

Trait Input 

pub trait Input {
    type Signal;

    // Required method
    fn get_input(&self) -> Self::Signal;
}
Structs that implement the Input trait represent physical or logical inputs to the keyboard. They can be anything from a momentary switch seen in typical keyboards to analog inputs from hall effect sensors or a varistor, to inputs from software on a host machine

Required Associated Types

Required Methods

fn get_input(&self) -> Self::Signal

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors