InputConfig

Trait InputConfig 

pub trait InputConfig<S> { }
Marker trait indicating that the implementing struct can be used as a configuration which read a signal of type S

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors